import { Body, Controller, HttpCode, Post } from '@nestjs/common';
import { ApiTags } from '@nestjs/swagger';
import { RegisterDto } from './models/dto/register.dto';
import { RegisterService } from './register.service';

@Controller('auth/register')
@ApiTags('Auth')
export class RegisterController {
  constructor(private readonly registerService: RegisterService) {}

  /**
   * Registers a new user
   *
   * @throws {400} Bad request
   * @throws {409} Email already used
   * @throws {500} Internal server error
   */
  @Post('')
  @HttpCode(204)
  async register(@Body() body: RegisterDto): Promise<void> {
    await this.registerService.register(
      body.email,
      body.username,
      body.password,
    );
  }
}
