import {
  ConflictException,
  Injectable,
  UnauthorizedException,
} from '@nestjs/common';
import { PrismaService } from '../helper/prisma.service';
import { CipherService } from '../helper/cipher.service';
import {
  EmailVerifications,
  Passkeys,
  TwoFactorAuth,
  Users,
} from '@prisma/client';
import { UserEntity } from './models/entities/user.entity';

@Injectable()
export class RegisterService {
  constructor(
    private readonly prismaService: PrismaService,
    private readonly cipherService: CipherService,
  ) {}

  async register(
    email: string,
    username: string,
    password: string,
  ): Promise<void> {
    const emailExists: Users = await this.prismaService.users.findFirst({
      where: {
        email,
      },
    });
    if (emailExists) throw new ConflictException('Email already registered');
    const hashedPassword: string = this.cipherService.hashPassword(password);
    await this.prismaService.users.create({
      data: {
        id: Bun.randomUUIDv7(),
        email,
        username,
        password: hashedPassword,
        token_id: this.cipherService.generateRandomBytes(),
      },
    });
  }
}
